@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
@@ -72,17 +72,19 @@ WWW::SFDC::Partner - Interface to the Salesforce.com Partner API
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
-    my @objects = WWW::SFDC::Partner->instance(creds => {
+    my $client =  WWW::SFDC->new(
         username => "foo",
         password => "bar",
         url      => "url",
-    })->query("SELECT field, ID FROM Object__c WHERE conditions");
+    );
 
-    WWW::SFDC::Partner->instance()->update(
+    my @objects = $client->Partner->query("SELECT field, ID FROM Object__c WHERE conditions");
+
+    $client->update(
         map { $_->{field} =~ s/baz/bat/ } @objects
     );
 
@@ -90,7 +92,7 @@ version 0.30
 
 =head2 setPassword
 
-    WWW::SFDC::Partner->instance()->setPassword(Id=>$ID, Password=$newPassword);
+   $client->Partner->setPassword(Id => $ID, Password => $newPassword);
 
 =head1 BUGS
 
