@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 use Log::Log4perl ':easy';
 use Scalar::Util 'blessed';
@@ -109,15 +109,15 @@ WWW::SFDC::Tooling - Interface to the Salesforce.com Tooling API
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
-   my $result = SFDC::tooling->instance(creds => {
+   my $result = WWW::SFDC->new(
     username => $USER,
     password => $PASS,
     url => $URL
-   })->executeAnonymous("System.debug(1);");
+   )->Tooling->executeAnonymous("System.debug(1);");
 
 Note that $URL is the _login_ URL, not the Tooling API endpoint URL - which gets calculated internally.
 
@@ -131,11 +131,11 @@ Note that $URL is the _login_ URL, not the Tooling API endpoint URL - which gets
 
 =head2 executeAnonymous
 
-    WWW::SFDC::Tooling->instance()->executeAnonymous("system.debug(1);")
+    $client->Tooling->executeAnonymous("system.debug(1);")
 
 =head2 runTests
 
-  SFDC::Tooling->instance()->runTests('name','name2');
+  $client->Tooling->runTests('name','name2');
 
 =head2 runTestsAsynchronous
 
